'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var SUFFIX_AGO = 'ago';
var SUFFIX_FROM_NOW = 'from now';

var UNITS = [{
  name: 'year',
  getter: function getter(date) {
    return date.getUTCFullYear();
  },
  setter: function setter(date, value) {
    return date.setYear(value);
  }
}, {
  name: 'month',
  getter: function getter(date) {
    return date.getMonth();
  },
  setter: function setter(date, value) {
    return date.setMonth(value);
  }
}, {
  name: 'week',
  getter: function getter(date) {
    return date.getDate() / 7;
  },
  setter: function setter(date, value) {
    return date.setDate(value * 7);
  }
}, {
  name: 'day',
  getter: function getter(date) {
    return date.getDate();
  },
  setter: function setter(date, value) {
    return date.setDate(value);
  }
}, {
  name: 'hour',
  getter: function getter(date) {
    return date.getHours();
  },
  setter: function setter(date, value) {
    return date.setHours(value);
  }
}, {
  name: 'minute',
  getter: function getter(date) {
    return date.getMinutes();
  },
  setter: function setter(date, value) {
    return date.setMinutes(value);
  }
}, {
  name: 'second',
  getter: function getter(date) {
    return date.getSeconds();
  },
  setter: function setter(date, value) {
    return date.setSeconds(value);
  }
}];

function getUnitByName(unitName) {
  var unit = void 0;

  for (var i = 0; i <= UNITS.length; i++) {
    unit = UNITS[i];

    if (unit.name === unitName) {
      return unit;
    }
  }

  return undefined;
}

var REGEXP = new RegExp('^([0-9]+)\\s(' + UNITS.map(function (unit) {
  return unit.name;
}).join('|') + ')s?\\s(' + SUFFIX_AGO + '|' + SUFFIX_FROM_NOW + ')$');

function parser(input) {
  var date = void 0;

  if (input) {
    if (input === 'now') {
      date = new Date();
    } else {
      var matches = input.match(REGEXP);

      if (matches) {
        date = new Date();

        var _matches = _slicedToArray(matches, 4);

        var amount = _matches[1];
        var unitName = _matches[2];
        var suffix = _matches[3];

        var _getUnitByName = getUnitByName(unitName);

        var getter = _getUnitByName.getter;
        var setter = _getUnitByName.setter;


        var currentValue = getter(date);

        var newValue = void 0;
        if (suffix === SUFFIX_AGO) {
          newValue = currentValue - parseInt(amount, 10);
        } else {
          newValue = currentValue + parseInt(amount, 10);
        }

        setter(date, newValue);
      }
    }
  }

  if (!date) {
    throw new Error('\'' + input + '\' it\'s an invalid date');
  }

  return date;
}

exports.default = parser;
module.exports = exports['default'];